==> qmmp_0.4.3.orig.tar.gz: qmmp-0.4.3/src/plugins/Output/oss/translations/oss_plugin_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<context>
    <name>OutputOSSFactory</name>
    <message>
        <location filename="../outputossfactory.cpp" line="36"/>
        <source>OSS Plugin</source>
        <translation>OSS プラグイン</translation>
    </message>
    <message>
        <location filename="../outputossfactory.cpp" line="56"/>
        <source>About OSS Output Plugin</source>
        <translation>OSS 出力プラグインについて</translation>
    </message>
    <message>
        <location filename="../outputossfactory.cpp" line="57"/>
        <source>Qmmp OSS Output Plugin</source>
        <translation>QMMP OSS 出力プラグイン</translation>
    </message>
    <message>
        <location filename="../outputossfactory.cpp" line="58"/>
        <source>Writen by: Yuriy Zhuravlev &lt;slalkerg@gmail.com&gt;</source>
        <translation>制作: Юрий Журавлёв (Yuriy Zhuravlev) &lt;slalkerg@gmail.com&gt;</translation>
    </message>
    <message>
        <location filename="../outputossfactory.cpp" line="59"/>
        <source>Based on code by: Brad Hughes &lt;bhughes@trolltech.com&gt;</source>
        <translation>Brad Hughes &lt;bhughes@trolltech.com&gt; 氏のコードを利用</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>OSS Plugin Settings</source>
        <translation>OSS プラグイン設定</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="30"/>
        <source>Device Settings</source>
        <translation>デバイス設定</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="42"/>
        <source>Audio device</source>
        <translation>音響デバイス</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="58"/>
        <source>Mixer device</source>
        <translation>ミキサーデバイス</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="81"/>
        <source>Advanced Settings</source>
        <translation>上級設定</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="93"/>
        <source>Soundcard</source>
        <translation>サウンドカード</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="157"/>
        <source>Buffer time (ms):</source>
        <translation>バッファ時間 (ミリ秒):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="167"/>
        <source>Period time (ms):</source>
        <translation>割り込み間隔 (ミリ秒):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="197"/>
        <source>PCM over Master</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="224"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="231"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
</TS>

==> qmmp-0.9.2-1.00.tar.gz: qmmp-0.9.2/src/plugins/Output/oss/translations/oss_plugin_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<context>
    <name>OutputOSSFactory</name>
    <message>
        <location filename="../outputossfactory.cpp" line="36"/>
        <source>OSS Plugin</source>
        <translation>OSS プラグイン</translation>
    </message>
    <message>
        <location filename="../outputossfactory.cpp" line="56"/>
        <source>About OSS Output Plugin</source>
        <translation>OSS 出力プラグインについて</translation>
    </message>
    <message>
        <location filename="../outputossfactory.cpp" line="57"/>
        <source>Qmmp OSS Output Plugin</source>
        <translation>QMMP OSS 出力プラグイン</translation>
    </message>
    <message>
        <location filename="../outputossfactory.cpp" line="58"/>
        <source>Written by: Yuriy Zhuravlev &lt;slalkerg@gmail.com&gt;</source>
        <translation>制作: Юрий Журавлёв (Yuriy Zhuravlev) &lt;slalkerg@gmail.com&gt;</translation>
    </message>
    <message>
        <location filename="../outputossfactory.cpp" line="59"/>
        <source>Based on code by: Brad Hughes &lt;bhughes@trolltech.com&gt;</source>
        <translation>Brad Hughes &lt;bhughes@trolltech.com&gt; 氏のコードを基に作成</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>OSS Plugin Settings</source>
        <translation>OSS プラグイン設定</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="33"/>
        <source>Device Settings</source>
        <translation>デバイス設定</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Audio device</source>
        <translation>音響デバイス</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>Mixer device</source>
        <translation>ミキサーデバイス</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="84"/>
        <source>Advanced Settings</source>
        <translation>上級設定</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="96"/>
        <source>Soundcard</source>
        <translation>サウンドカード</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="160"/>
        <source>Buffer time (ms):</source>
        <translation>バッファー時間 (ミリ秒):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="170"/>
        <source>Period time (ms):</source>
        <translation>割り込み間隔 (ミリ秒):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="200"/>
        <source>PCM over Master</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
